@@ -1,7 +1,7 @@
 package Perinci::CmdLine::cryp;
 
-our $DATE = '2018-04-03'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2018-05-05'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -46,6 +46,16 @@ sub hook_config_file_section {
         return [204];
     }
 
+    if ($section_name =~ m!\Aarbit-strategy\s*/\s*([^/]++)\z!) {
+        my $strategy = $1;
+        $r->{_cryp}{arbit_strategy}{$strategy} //= {};
+        for (keys %$section_content) {
+            $r->{_cryp}{arbit_strategy}{$strategy}{$_} =
+                $section_content->{$_};
+        }
+        return [204];
+    }
+
     [200];
 }
 
@@ -64,7 +74,7 @@ Perinci::CmdLine::cryp - Perinci::CmdLine::Lite subclass to read entities from c
 
 =head1 VERSION
 
-This document describes version 0.004 of Perinci::CmdLine::cryp (from Perl distribution Perinci-CmdLine-cryp), released on 2018-04-03.
+This document describes version 0.005 of Perinci::CmdLine::cryp (from Perl distribution Perinci-CmdLine-cryp), released on 2018-05-05.
 
 =head1 HOMEPAGE
 
